@@ -23,6 +23,10 @@ class Prices:
     def returns(self):
         return self._obj.returns
 
+    @property
+    def log_returns(self):
+        return self._obj.log_returns
+
     @property
     def weekly_returns(self):
         return self._obj.weekly_returns
